@@ -46,8 +46,7 @@ def get_settings():
             "datasource_boa_vista_url": os.getenv(
                 "SNATCH_DATASOURCE_BOA_VISTA_URL", "http://datasource_boa_vista"
             ),
-        },
-        "project": {"aws_region": os.getenv("PROJECT_AWS_REGION", "us-east-1")},
+        }
     }
     config.update(get_environment_from_secrets_manager())
 
